@@ -6,7 +6,7 @@
 # the Apache License 2.0.  The full license can be found in the LICENSE file.
 #
 
-from .client import PerspectiveClient
+from .base import PerspectiveClient
 
 try:
     from .aiohttp import PerspectiveAIOHTTPClient, websocket as aiohttp_websocket
